@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use feature qw/state/;
 
-our $VERSION = '0.000005'; # TRIAL
+our $VERSION = '0.000007'; # TRIAL
 
 use Carp qw/croak confess/;
 $Carp::Internal{ (__PACKAGE__) }++;
@@ -1437,6 +1437,23 @@ The ORM class
         print $person->field('first_name') . "\n"
     }
 
+    my $new_select = $select->limit(5)->order_by('surname')->omit(@large_fields);
+    my $iterator = $new_select->iterator; # Query is actually sent to DB here.
+    while (my $row = $iterator->next) {
+        ...
+    }
+
+    # Start an async query
+    my $async = $select->async->iterator;
+
+    while (!$async->ready) {
+        do_something_else();
+    }
+
+    while (my $item = $iterator->next) {
+        ...
+    }
+
 =head1 A NOTE ON AFFINITY
 
 Whenever you define a column in DBIx::QuickORM it is necessary for the orm to
